Module entity
thinlinelib
0.3.1
Module entity
Module Items
Structs
Enums
Traits
In crate thinlinelib
thinlinelib
Module
entity
Structs

Entity
The representation of an Entity as a possbile generic node on the abstract syntax tree. An Entity has to be kind of a EntityType.
Enums

Entity
Type
The different types an Entitiy can have.
Traits

Entity
Conversion